"""Patches main module
"""
from pypatches.log import *
